﻿' EXAMPLE - SQL07 for Visual Basic using ADO.NET
' This example shows how to use parameters with SQL commands.  A database
' is created and then data is inserted with positioned parameters and then
' with named parameters.  Finally the data is read out and displayed.
' 
' The following methods are illustrated:
'     Raima.Rdm.RdmConnection:
'         ChangeDatabase(string) Method
'         Close() Method
'         CreateCommand() Method
'         Open() Method
'         RdmConnection() Constructor
'     Raima.Rdm.RdmCommand:
'         CommandText Property
'         ExecuteNonQuery() Method
'         ExecuteReader() Method
'     Raima.Rdm.RdmDataReader:
'         Item[int] Property
'         Read() Method
'     Raima.Rdm.RdmParameterCollection
'         Add(RdmParameter) Method
'         Add(String, RdmType) Method
'         Clear() Method
'         Item[int] Property
'         Item[string] Property
' 
' They are fully document in http://docs.raima.com/rdm/.
' 
' For simplicity this example does not catch any thrown execptions
' but good programming practices would dictate that this occur in
' a full application.

' Raima.Rdm is the system module that contains the ADO.NET
' data provider for RDM
Imports Rdm = Raima.Rdm

Module SQL07
    Sub DropDatabase(conn As Rdm.RdmConnection, name As String)
        Dim cmd As Rdm.RdmCommand
        cmd = conn.CreateCommand()

        ' Attempt to drop this database.  If the database does not already
        ' exist this will fail and we simply ignore the failure for this
        ' sample.
        Try
            cmd.CommandText = "DROP DATABASE " + name
            cmd.ExecuteNonQuery()
        Catch ex As Exception
        End Try

    End Sub

    Sub CreateThisDatabase(conn As Rdm.RdmConnection, name As String, cmds() As String)
        Dim cmd As Rdm.RdmCommand
        cmd = conn.CreateCommand()

        cmd.CommandText = "CREATE DATABASE " + name
        cmd.ExecuteNonQuery()

        For Each c In cmds
            cmd.CommandText = c
            cmd.ExecuteNonQuery()
        Next

        cmd.CommandText = "COMMIT"
        cmd.ExecuteNonQuery()

        cmd.CommandText = "CLOSE " + name
        cmd.ExecuteNonQuery()
    End Sub

    Sub CreateDatabases(conn As Rdm.RdmConnection)
        ' Drop any existing copy of the databases.
        DropDatabase(conn, "SQL07")

        ' Attempt to create the database
        Dim cmds(0) As String
        cmds(0) = "CREATE TABLE Table1 (id INTEGER PRIMARY KEY, str CHAR(30))"
        CreateThisDatabase(conn, "SQL07", cmds)
    End Sub

    Sub Main()
        ' Create the connection with a simple connection string
        Dim conn As Rdm.RdmConnection
        conn = New Rdm.RdmConnection("host=local;openmode=x")
        conn.Open()

        CreateDatabases(conn)

        ' Open the database
        conn.ChangeDatabase("SQL07")

        ' Create a new command
        Dim cmd As Rdm.RdmCommand
        cmd = conn.CreateCommand()

        ' Insert three rows into the table using positioned parameters
        cmd.CommandText = "INSERT INTO Table1 VALUES ?, ?"
        cmd.Parameters.Add(New Rdm.RdmParameter())
        cmd.Parameters.Add(New Rdm.RdmParameter())

        For ii = 1 To 3
            cmd.Parameters.Item(0).Value = ii
            cmd.Parameters.Item(1).Value = "positioned " + Convert.ToString(ii)
            cmd.ExecuteNonQuery()
        Next

        ' Insert three rows into the table using named parameters
        cmd.Parameters.Clear()
        cmd.CommandText = "INSERT INTO Table1 VALUES :idparm, :strparm"
        cmd.Parameters.Add("idparm", Rdm.RdmType.Int32)
        cmd.Parameters.Add("strparm", Rdm.RdmType.AnsiString)

        For ii = 4 To 7
            cmd.Parameters.Item("idparm").Value = ii
            cmd.Parameters.Item("strparm").Value = "named " + Convert.ToString(ii)
            cmd.ExecuteNonQuery()
        Next

        ' Scan through the data, displaying the rows
        cmd.Parameters.Clear()
        cmd.CommandText = "SELECT id, str FROM Table1"
        Dim reader As Rdm.RdmDataReader
        reader = cmd.ExecuteReader()

        While (reader.Read())
            Console.WriteLine(Convert.ToString(reader.Item(0)) + " -- " + reader.Item(1))
        End While

        conn.Close()

        Console.WriteLine("Hit <Enter> to continue")
        Console.ReadLine()
    End Sub
End Module
